// java wrapper for vtkCameraPass object
//

package vtk;
import vtk.*;

public class vtkCameraPass extends vtkRenderPass
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void ReleaseGraphicsResources_2(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_2(id0); }

  private native long GetDelegatePass_3();
  public vtkRenderPass GetDelegatePass() {
    long temp = GetDelegatePass_3();

    if (temp == 0) return null;
    return (vtkRenderPass)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetDelegatePass_4(vtkRenderPass id0);
  public void SetDelegatePass(vtkRenderPass id0)
    { SetDelegatePass_4(id0); }

  private native void SetAspectRatioOverride_5(double id0);
  public void SetAspectRatioOverride(double id0)
    { SetAspectRatioOverride_5(id0); }

  private native double GetAspectRatioOverride_6();
  public double GetAspectRatioOverride()
    { return GetAspectRatioOverride_6(); }

  public vtkCameraPass() { super(); }

  public vtkCameraPass(long id) { super(id); }
  public native long   VTKInit();

}
